<?php

namespace Teknisa\PLA\Modules\Medicao\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO;

class RestoIngestaController extends \Teknisa\GER\Controllers\TeknisaCrud {

	protected $dataSourceName;
	protected $parameterBagColumns;
	protected $crudService;
	protected $parameterBag;
	protected $connection;

	public function __construct($crudService, $parameterBag, $dataSourceManager, $connection) {
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->dataSourceManager = $dataSourceManager;
        $this->connection = $connection;
    }

    public function retornaDataSetStripe(DTO\Request $request, DTO\Response $response) {

    	$mediaMesDia = $this->retornaMediaMesDia($request);
    	$maiorPct = $this->retornaMaiorPct($request);
    	$menorPct = $this->retornaMenorPct($request);
    	$meta = $this->retornaMeta($request);


    	$datasetStripe = array(
			'totrestinge' => $mediaMesDia['totrestinge'],
			'pemediaperc' => $mediaMesDia['pemediaperc'],
			'mediadia' => $mediaMesDia['mediadia'],
			'maiorpct' => $maiorPct['pemax'],
			'menorpct' => $menorPct['pemin'],
			'meta' => $meta['meta']
		);
		$response->addDataset(new DataSet('datasetStripe', array($datasetStripe)));
	}

	public function retornaMediaMesDia(DTO\Request $request) {

		$this->dataSourceName = 'pla0110_resto_total_media_mes_dia';
		$this->parameterBagColumns = array('CDFILIAL', 'NRORG', 'CDSERVFILI', 'DTMESCARD');
		$filterCriteria = $request->getFilterCriteria();
		$filterCriteria->setDataSourceName($this->dataSourceName);
		$newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, $this->parameterBagColumns);
		$dataSet = $this->dataSourceManager->findBy($newFilterCriteria);
		$rows = $dataSet->getRows();

		if (isset($rows[0])) {

			$totrestinge = $rows[0]['TOTRESTINGE'];
			$pemediaperc = $rows[0]['PEMEDIAPERC'];
			$mediadia = $rows[0]['MEDIADIA'];

		} else {

			$totrestinge = 0;
			$pemediaperc = 0;
			$mediadia = 0;
		}

		return array(
			'totrestinge' => $totrestinge,
			'pemediaperc' => $pemediaperc,
			'mediadia' => $mediadia,
		);

    }

    public function retornaMaiorPct(DTO\Request $request) {

    	$this->dataSourceName = 'pla0110_resto_pemax';
		$this->parameterBagColumns = array('CDFILIAL', 'NRORG', 'CDSERVFILI', 'DTMESCARD');
		$filterCriteria = $request->getFilterCriteria();
		$filterCriteria->setDataSourceName($this->dataSourceName);
        $newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, $this->parameterBagColumns);
		$dataSet = $this->dataSourceManager->findBy($newFilterCriteria);
		$rows = $dataSet->getRows();

		if (isset($rows[0])) {

			$pemax = $rows[0]['PEMAX'];

		} else {

			$pemax = 0;
		}

		return array(
			'pemax' => $pemax,
		);

    }

    public function retornaMenorPct(DTO\Request $request) {

    	$this->dataSourceName = 'pla0110_resto_pemin';
		$this->parameterBagColumns = array('CDFILIAL', 'NRORG', 'CDSERVFILI', 'DTMESCARD');
		$filterCriteria = $request->getFilterCriteria();
		$filterCriteria->setDataSourceName($this->dataSourceName);
        $newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, $this->parameterBagColumns);
		$dataSet = $this->dataSourceManager->findBy($newFilterCriteria);
		$rows = $dataSet->getRows();

		if (isset($rows[0])) {

			$pemin = $rows[0]['PEMIN'];

		} else {

			$pemin = 0;
		}
		
		return array(
			'pemin' => $pemin,
		);

    }
    public function retornaMeta(DTO\Request $request) {

    	$this->dataSourceName = 'pla0110_resto_meta';
		$filterCriteria = $request->getFilterCriteria();
		
		$conditions = array_filter($filterCriteria->getConditions(), function($condition) {
			return $condition["columnName"] !== "CDSERVFILI";
		});
		$dataSet = $this->crudService->getFilteredDataSet($this->dataSourceName, $conditions);
		$rows = $dataSet->getRows();
		
		$meta = (isset($rows[0]['VRPEMETAREIN']))? $rows[0]['VRPEMETAREIN'] : 0;
		return array(
			'meta' => $meta,
		);

    }
    
    public function findParamPlaneja(DTO\Request $request, DTO\Response $response) {
		$row = $request->getRow();

		$query = "SELECT VRPESOPORCREIN FROM PARAMPLANEJA WHERE CDFILIAL = :CDFILIAL";
        $stmt = $this->connection->prepare($query);
        $params = array(
            "CDFILIAL"   => $row['CDFILIAL']
        );
        $stmt->execute($params);
        $result = $stmt->fetchAll(\PDO::FETCH_ASSOC);
		$response->addDataset(new DataSet('data', $result));
	}
	
	public function saveInlineEdit(DTO\Request $request, DTO\Response $response) {
		$rows = $request->getDataSet()->getRows();
        
		foreach($rows as $row){
			try {
				$query = "UPDATE CARDADIA SET CDSERVFILI = :CDSERVFILI, DTCARDAPIO = :DTCARDAPIO, QTCOMESTICAR = :QTCOMESTICAR, QTCOMEFETRI = :QTCOMEFETRI, VRPESPORPERCRI = :VRPESPORPERCRI, QTRESTINGECA = :QTRESTINGECA, CDMAIORPRERI = :CDMAIORPRERI, CDFILAUXPRRI = :CDFILAUXPRRI, IDEFETINFORI = :IDEFETINFORI, CDDIETPAD = :CDDIETPAD WHERE CDFILIAL = :CDFILIAL AND NRCARDAPIO = :NRCARDAPIO";
    			$stmt = $this->connection->prepare($query);
				$params = array(
		            "CDSERVFILI"   => $row['CDSERVFILI'],
		            "DTCARDAPIO"   => $row['DTCARDAPIO'],
		            "QTCOMESTICAR"   => isset($row['QTCOMESTICAR']) ? $row['QTCOMESTICAR'] : 0,
		            "QTCOMEFETRI"   => isset($row['QTCOMEFETRI']) ? $row['QTCOMEFETRI'] : 0,
		            "VRPESPORPERCRI"   => isset($row['VRPESPORPERCRI']) ? $row['VRPESPORPERCRI'] : 0,
		            "QTRESTINGECA"   => isset($row['QTRESTINGECA']) ? $row['QTRESTINGECA'] : 0,
		            "CDMAIORPRERI"   => isset($row['CDMAIORPRERI']) ? $row['CDMAIORPRERI'] : null,
		            "CDFILAUXPRRI"   => isset($row['CDFILAUXPRRI']) ? $row['CDFILAUXPRRI'] : null,
		            "IDEFETINFORI"   => isset($row['IDEFETINFORI']) ? $row['IDEFETINFORI'] : null,
		            "CDDIETPAD"   => isset($row['CDDIETPAD']) ? $row['CDDIETPAD'] : null,
		            "CDFILIAL"   => $row['CDFILIAL'],
		            "NRCARDAPIO"   => $row['NRCARDAPIO']
	        	);

	        	$stmt->execute($params);
	        	
			} catch (\Exception $e) {
            	throw new \Exception($e->getMessage());
        	}
		}
	}
	
}