<?php
namespace Teknisa\PLA\Modules\Parametros\Services;

use Teknisa\Libs\Util\XLS\FileLoader;
use Teknisa\Libs\Util\XLS\FileReader;
use Teknisa\Libs\Util\XLS\Table;
use Teknisa\Libs\Util\XLS\Exception;
use Teknisa\Libs\Util\XLS\Filter;
use PHPExcel_Cell;
use PHPExcel_Shared_Date;
use Teknisa\Libs\Util\Environment;

use Teknisa\PLA\Modules\Prato\Services\PratoService;

class Ger08400CadastramentosAutomaticoService {
    
    protected $connection;
    protected $environment;
    protected $prato;
    const PRODUCT_NOT_FOUND = 'NOT_FOUND';
    
    public function __construct(Environment $environment, $connection, PratoService $prato) {
        $this->environment   = $environment;
        $this->connection = $connection;
        $this->prato = $prato;
    }
    
    public function readXls($row){
        $file = $row['FILE'];
        $columnNames = $row['CAMPOS'];
        $sheetsToLoad = array('Sheasdasdsadet1');
        $xlsFile = FileLoader::loadFromBase64($file['content'], $file['name']);
        if(!$xlsFile){
            throw new \Exception(self::IMPORT_LOAD_FILE_ERROR);
        }
        $worksheet = $xlsFile->getActiveSheet();
        $table = FileReader::readWorksheetTable($worksheet, $columnNames);
        
        return $table;
    }
    
    private function getCdProduto($CDARVPROD){
        $NRORG = $this->environment->getNrOrg();
        $sql = "SELECT CDPRODUTO FROM PRODUTO WHERE CDARVPROD = :CDARVPROD AND CDPRODUTO = CDPRODESTO AND NRORG = :NRORG";
        $params = array( 
            'CDARVPROD' => $CDARVPROD,
            'NRORG'     => $NRORG
        );
        $stmt = $this->connection->prepare($sql);
        $stmt->execute($params);
        $produto = $stmt->fetch();
        $result = self::PRODUCT_NOT_FOUND;
        if($produto !== false){
            $result = $produto['CDPRODUTO'];
        }
        return $result; 
    }
    
    private function throwExceptionJson($message){
        throw new \Exception(json_encode(array($message)));
    }

    public function formatXls(Table $table, $tabela){
        $columnsReference = $table->getColumnsReference();
        $tableRows = $table->getRows();
        $columnsNumber = $table->getNumberOfColumns();
        $i = 0;
        $erros = array();
        $rowAnt = array();
        $produtos = array();
        $cdpictprat = $this->prato->getCdPictPrat();
        
        foreach ($tableRows as $chave => &$row) {
            $chave = $chave+2;
            $row = $row['content'];
            $inconsistentInfoProduct = false;
            $originalRow = new \ArrayObject($row);
            $originalRow = $originalRow->getArrayCopy();

            for($column = 0; $column < $columnsNumber; $column++){
                $columnLetterIndex = PHPExcel_Cell::stringFromColumnIndex($column);
                $columnName = $columnsReference[$columnLetterIndex];
                $currentPlate = $row['CDPRATO'];
                $isCompleteLevel = $this->prato->hasCompleteLevel($row['CDPRATO'], $cdpictprat);
                $CDARVPROD = $row['CDARVPROD'];
                $CDPRODUTO = "";
                try {
                    if ($tabela == 'PRATO_RECEITA_PADRAO') {
                        switch($columnName){
                            case 'CDARVPROD':
                                if($CDARVPROD){
                                    if(!$isCompleteLevel){
                                        $this->throwExceptionJson("Produto só pode ser informado para prato com nível completo");
                                    }
                                
                                    $CDPRODUTO = $produtos[$CDARVPROD] ?? $this->getCdProduto($CDARVPROD);
                                    $productExists = $CDPRODUTO !== self::PRODUCT_NOT_FOUND;
                                    if($productExists){
                                        $produtos[$CDARVPROD] = $CDPRODUTO;
                                    } else {
                                        $this->throwExceptionJson("Produto não cadastrado ou não é um produto de estoque.");
                                    }
                                    $row['CDPRODUTO'] = $CDPRODUTO;
                                    $row['CDARVPROD'] = $CDARVPROD;
                                    $colunas = array(
                                        'CDPRATO'      => $row['CDPRATO'],
                                        "CDPRODUTOANT" => $rowAnt,
                                        'CDPRODUTO'    => $CDPRODUTO,
                                        'SGUNIPROD'    => $row['SGUNIPROD'],
                                        'QTPRODUTO'    => $row['QTPRODUTO']
                                    );
                                    
                                    $valor = $this->prato->formatValue($colunas, 'CDPRODUTO');
                                    
                                    $row['CDPRODUTO'] = $valor['CDPRODUTO'];
                                    $row['QTPRODUTO'] = $valor['QTPRODUTO'];
                                    $row['SGUNIPROD'] = $valor['SGUNIPROD'];
                                    
                                    if($row['CDPRODUTO'] != null ){
                                        $objectPrat = array(
                                            'CDPRATO'   => $row['CDPRATO'],
                                            'CDPRODUTO' => $row[$columnName]
                                        );
                                        array_push($rowAnt, $objectPrat);
                                    } 
                                }
                                break;
                            case 'CDPRATO':
                            case 'NMPRATO':
                                $row[$columnName] = $this->prato->formatValue($row[$columnName], $columnName, $cdpictprat);
                                break;
                            case 'SGUNIDPRATO':
                                if(!$isCompleteLevel && $originalRow[$columnName]){
                                    $this->throwExceptionJson("Unidade do prato só pode ser informada para prato com nível completo");
                                }
                                if($isCompleteLevel) $row[$columnName] = $this->prato->formatValue($row[$columnName], $columnName);
                                break;
                            case 'SGUNIPROD':
                            case 'QTPRODUTO':
                            case 'QTPERDA':
                                if(!$isCompleteLevel){
                                    /* 
                                        Preenchida colunas relativas a produto,
                                        para um nível de prato incompleto
                                    */
                                    if( $originalRow[$columnName] && !$inconsistentInfoProduct && !$CDARVPROD){
                                        $inconsistentInfoProduct = true;
                                        $this->throwExceptionJson("Informações relativas a produto definidas sem um produto associado");
                                    }
                                }
                                $row[$columnName] = $this->prato->formatValue($row[$columnName], $columnName, $cdpictprat);
                                break;
                        }
                    } else {
                        throw new \Exception('Tabela para importação não existe.');
                    }
                } catch (\Exception $e) {
                    $lista_erros = json_decode($e->getMessage());
                    if (count($lista_erros)>1){
                        foreach ($lista_erros as $erro){
                            $erros[] = array('IDREF' => $chave, 'DESCERROR' => $erro);
                        }
                    } else array_push($erros, array('IDREF' => $chave, 'DESCERROR' => $lista_erros));
                }
                
            }
            $row["ROWNUM"] = $i;

            $i++;
        }
        return array('ROWS'=>$tableRows, 'ERROR'=>$erros);
    }

}