<?php

namespace Teknisa\PLA\Modules\Requisicao\Controllers;

use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DTO;

class Pla00900 extends \Zeedhi\Framework\Controller\Report {
	protected $dataSourceName;
	protected $environment;
	protected $connection;
	protected $newCode;
	protected $qr2Strategy;
	protected $dataSourceManager;
	protected $entityManager;
	protected $birtStrategy;
    
	public function __construct($reportService, $environment, $connection, $newCode, $dataSourceManager, $entityManager, $qr2Strategy, $birtStrategy){
		$this->reportService = $reportService;
        $this->environment = $environment;
		$this->entityManager       = $entityManager;
        $this->connection = $connection;
		$this->qr2Strategy = $qr2Strategy;
		$this->newCode = $newCode;
		$this->dataSourceManager = $dataSourceManager;
		$this->birtStrategy  = $birtStrategy;
	}
	
	protected $reportMapping = array (
    	'pla05700' => array (
            'strategy' => 'QR2',
            'parameterMapping' => 
            array (
                'CDFILIAL'       => 'P_CDFILIAL',
                'DTINICIAL'      => 'P_DTINICIAL',
                'DTFINAL'        => 'P_DTFINAL',
                'CDSERVFILI'     => 'P_CDSERVFILI',
                'TAMNIV'		 => 'P_TAMNIV',
                'NRLINHABRANCA'  => 'P_NRLINHABRANCA'
            )
        ),
        'pla00900' => array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
                'CDFILIAL'       => 'P_CDFILIAL',
                'CDSERVFILI'     => 'P_CDSERVFILI',
                'DTPREVRETI'     => 'P_DTPREVRETI',
                'TAMNIV'		 => 'P_TAMNIV',
                'NRREQUEXTR'     => 'P_NRREQUEXTR',
                'NRLINHABRANCA'  => 'P_NRLINHABRANCA',
                'CDOPERADOR'     => 'P_CDOPERADOR',
                'NMOPERADOR'     => 'P_NMOPERADOR',
                'CDSETORCOZ'     => 'P_CDSETORCOZ',
                'NMSETORCOZ'     => 'P_NMSETORCOZ',
                'CDPICTPROD'     => 'P_CDPICTPROD',
                'NRORG'          => 'P_NRORG'
            )
        ),
        'pla00901' => array (
            'strategy' => 'BIRT',
            'parameterMapping' => 
            array (
                'CDFILIAL'       => 'P_CDFILIAL',
                'CDSERVFILI'     => 'P_CDSERVFILI',
                'DTPREVRETI'     => 'P_DTPREVRETI',
                'TAMNIV'		 => 'P_TAMNIV',
                'NRREQUEXTR'     => 'P_NRREQUEXTR',
                'NRLINHABRANCA'  => 'P_NRLINHABRANCA',
                'CDOPERADOR'     => 'P_CDOPERADOR',
                'NMOPERADOR'     => 'P_NMOPERADOR',
                'CDSETORCOZ'     => 'P_CDSETORCOZ',
                'NMSETORCOZ'     => 'P_NMSETORCOZ',
                'CDPICTPROD'     => 'P_CDPICTPROD',
                'NRORG'          => 'P_NRORG'
            )
        )
    );

    public function retornaServicos($cdfilial, $nrorg) {
        $sql = "SELECT DISTINCT CDSERVFILI FROM SERVICO WHERE CDFILIAL = :CDFILIAL AND NRORG = :NRORG";
            
        $params = array(
            'NRORG'        => $nrorg,
            'CDFILIAL'     => $cdfilial
        );

        try {
            $lista = $this->entityManager->getConnection()->fetchAll($sql, $params);
            
            $listaServico = "";
            foreach($lista as $key => &$listaServ){
                $listaServico.= $listaServ['CDSERVFILI'].'_';
            }
            return $listaServico;
            
        } catch (\Exception $e) {
            throw $e;
        }
    }
	
    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        $row['TAMNIV'] = '10';
        $this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
        $this->qr2Strategy->setQr2Type($row['QR2TYPE']);
        
        $cdfilial    = $row['CDFILIAL'];
        $nrorg       = $row['NRORG'];

        if ($row['CDSERVFILI'] == 'T') {
            $row['CDSERVFILI'] = $this->retornaServicos($cdfilial, $nrorg);
        }
        
        $row['CDSETORCOZ'] = null;
        $row['NMSETORCOZ'] = null;
        
        
    }
	
}